@@ -1,4 +1,5 @@
 import json
+import os
 from datetime import date, datetime, time
 from tempfile import NamedTemporaryFile
 from unittest import skipIf
@@ -218,11 +219,15 @@ class ExportViewTest(TestCase):
         response = View.as_view()(build_request("/?_export=xlsx"))
         self.assertEqual(response.status_code, 200)
 
-        with NamedTemporaryFile(suffix=".xlsx") as tmp:
+        tmp = NamedTemporaryFile(suffix=".xlsx", delete=False)
+        try:
             tmp.write(response.content)
             tmp.seek(0)
             wb = load_workbook(tmp.name)
             self.assertIn(title, wb.sheetnames)
+        finally:
+            tmp.close()
+            os.unlink(tmp.name)
 
 
 class OccupationTable(tables.Table):
